/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the New BSD License (3-clause license).
 *
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the New BSD License (3-clause license)
 * for more details.
 *
 * You should have received a copy of the New BSD License (3-clause license)
 * along with this program/library; If not, see http://directory.fsf.org/wiki/License:BSD_3Clause/
 * for the New BSD License (3-clause license).
 */
package com.ebmwebsourcing.easycommons.lang;

import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;
import static org.junit.Assert.assertFalse;
import org.junit.Test;

/**
 * @author Mathieu CARROLLE - EBM WebSourcing
 */
public class StringHelperTest {

    @Test
    public void testIsNullOrEmptyWithNullObject() {
        assertTrue(StringHelper.isNullOrEmpty(null));
    }

    @Test
    public void testIsNullOrEmptyWithEmptyString() {
        assertTrue(StringHelper.isNullOrEmpty(new String("")));
    }

    @Test
    public void testIsNullOrEmptyWithNonEmptyString() {
        assertFalse(StringHelper.isNullOrEmpty(new String("John doe")));
    }

    @Test
    public void testNonNullValueWithNullObject() {
        Object obj = null;
        String result = StringHelper.nonNullValue(obj);
        assertNotNull(result);
        assertTrue(result.length() == 0);
    }

    @Test
    public void testNonNullValueWithNonNullObject() {
        Integer integer = new Integer(4);
        String result = StringHelper.nonNullValue(integer);
        assertNotNull(result);
        assertTrue(result.equals("4"));
    }

    @Test
    public void testEqualsWithNullInstance() {
        String s1 = null;
        String s2 = null;
        assertTrue(StringHelper.equal(s1, s2));
    }

    @Test
    public void testEqualsWithOneNullInstance() {
        String s1 = null;
        String s2 = "test";
        assertFalse(StringHelper.equal(s1, s2));
        assertFalse(StringHelper.equal(s2, s1));
    }

    @Test
    public void testEqualsWithNonNullInstance() {
        String s1 = "petals";
        String s2 = "petals";
        assertTrue(StringHelper.equal(s1, s2));
    }
}
